@@ -23,7 +23,7 @@ from __future__ import annotations
 from unittest import main
 
 from sdbus import DbusPropertyReadOnlyError
-from sdbus.proxies import FreedesktopDbus
+from sdbus_block.dbus_daemon import FreedesktopDbus
 
 from .common_test_util import TempDbusTest
 
@@ -31,6 +31,8 @@ from .common_test_util import TempDbusTest
 class TestSync(TempDbusTest):
 
     def test_sync(self) -> None:
+        self.bus.request_name('org.example.test', 0)
+
         s = FreedesktopDbus(self.bus)
         s.dbus_ping()
         s.dbus_introspect()
@@ -49,6 +51,19 @@ class TestSync(TempDbusTest):
 
         self.assertRaises(DbusPropertyReadOnlyError, test_invalid_assignment)
 
+        self.assertTrue(s.get_name_owner('org.example.test'))
+
+    def test_docstring(self) -> None:
+        from pydoc import getdoc
+
+        s = FreedesktopDbus(self.bus)
+
+        with self.subTest('Method doc'):
+            self.assertTrue(getdoc(s.get_connection_pid))
+
+        with self.subTest('Property doc (through class dict)'):
+            self.assertTrue(getdoc(s.__class__.__dict__['features']))
+
 
 if __name__ == '__main__':
     main()
